

SimpleResource
================================

.. currentmodule:: pyvo.registry.vao

.. autoclass:: SimpleResource
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~SimpleResource.accessurl
      ~SimpleResource.capability
      ~SimpleResource.contentlevel
      ~SimpleResource.description
      ~SimpleResource.identifier
      ~SimpleResource.ivoid
      ~SimpleResource.publisher
      ~SimpleResource.shortname
      ~SimpleResource.standardid
      ~SimpleResource.subject
      ~SimpleResource.tags
      ~SimpleResource.title
      ~SimpleResource.type
      ~SimpleResource.waveband

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~SimpleResource.describe
      ~SimpleResource.search
      ~SimpleResource.to_service

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: accessurl
   .. autoattribute:: capability
   .. autoattribute:: contentlevel
   .. autoattribute:: description
   .. autoattribute:: identifier
   .. autoattribute:: ivoid
   .. autoattribute:: publisher
   .. autoattribute:: shortname
   .. autoattribute:: standardid
   .. autoattribute:: subject
   .. autoattribute:: tags
   .. autoattribute:: title
   .. autoattribute:: type
   .. autoattribute:: waveband

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: describe
   .. automethod:: search
   .. automethod:: to_service

   
   